const mysql = require('mysql');

var secrets = require('../secrets.js');
var dbhost = secrets.dbhost;
var dbuser = secrets.dbuser;
var dbpassword = secrets.dbpassword;
var dbdatabase = secrets.dbdatabase;

const dbConfig = {
  host: dbhost,
  user: dbuser,
  password: dbpassword,
  database: dbdatabase
};

function getClassementObjectifs(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "SELECT Objectif.id as id,name,description,value,coef,realise FROM Objectif CROSS JOIN (SELECT SUM(score) as realise FROM Score WHERE deleted = 0) AS Realise WHERE Objectif.deleted = 0 ORDER BY value DESC;"
  con.connect();
  con.query(query, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function getAdminObjectifs(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "SELECT id,name,description,value,coef FROM Objectif WHERE deleted = 0 ORDER BY name ASC;"
  con.connect();
  con.query(query, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function addNewObjectif(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "INSERT INTO `Objectif` (`name`, `description`, `value`, `coef`) VALUES (?, ?, ?, ?);"
  var inserts = [req.body.name, req.body.description, req.body.value, req.body.coef];
  con.connect();
  con.query(query, inserts, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function updateObjectifName(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "UPDATE Objectif SET name = ? WHERE id=?;"
  var inserts = [req.body.name, req.body.id];
  con.connect();
  con.query(query, inserts, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function updateObjectifDescription(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "UPDATE Objectif SET description = ? WHERE id=?;"
  var inserts = [req.body.description, req.body.id];
  con.connect();
  con.query(query, inserts, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function updateObjectifValue(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "UPDATE Objectif SET value = ? WHERE id=?;"
  var inserts = [req.body.value, req.body.id];
  con.connect();
  con.query(query, inserts, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function updateObjectifCoef(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "UPDATE Objectif SET coef = ? WHERE id=?;"
  var inserts = [req.body.coef, req.body.id];
  con.connect();
  con.query(query, inserts, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function deleteObjectif(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "UPDATE Objectif SET deleted = 1 WHERE id=?;"
  var inserts = [req.body.id];
  con.connect();
  con.query(query, inserts, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

module.exports = { getClassementObjectifs, getAdminObjectifs, addNewObjectif, updateObjectifName, updateObjectifDescription, updateObjectifValue, updateObjectifCoef, deleteObjectif }
