const mysql = require('mysql');

var secrets = require('../secrets.js');
var dbhost = secrets.dbhost;
var dbuser = secrets.dbuser;
var dbpassword = secrets.dbpassword;
var dbdatabase = secrets.dbdatabase;

const dbConfig = {
  host: dbhost,
  user: dbuser,
  password: dbpassword,
  database: dbdatabase
};

function getClassementIndividuel(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "SELECT  Participant.id as id, Participant.name as name, score, Equipe.name AS equipe_name FROM Score  JOIN Participant ON Participant.id=Score.participantId  JOIN Equipe ON Score.equipeId = Equipe.id  WHERE  (Score.deleted = 0  AND  (Participant.deleted=0 AND Participant.id <> 'sprint'))  ORDER BY score DESC;"
  con.connect();
  con.query(query, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    let leader_indiv = {};
    for (const data of result) {
      if (data.id in leader_indiv) {
        if (leader_indiv[data.id].equipes.indexOf(data.equipe_name) == -1) {
          leader_indiv[data.id].equipes.unshift(data.equipe_name);
        }
        leader_indiv[data.id].score += data.score;
        leader_indiv[data.id].nbScores += 1;
      } else {
        leader_indiv[data.id] = {
          name: data.name,
          id: data.id,
          score: data.score,
          equipes: [data.equipe_name],
          nbScores: 1,
        }
      }
    }
    result = Object.keys(leader_indiv).map((key) => leader_indiv[key])
    result.sort((a, b) => (a.score < b.score) ? 1 : -1)
    return res.send(result)
  });
  con.end();
}

function getNombreParticipants(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "SELECT COUNT(id) as nombreParticipants FROM Participant WHERE deleted = 0;"
  con.connect();
  con.query(query, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function getParticipants(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "SELECT id,name FROM Participant WHERE deleted = 0 ORDER BY NAME ASC;"
  con.connect();
  con.query(query, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function getParticipantsIdentifiants(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "SELECT id FROM Participant WHERE deleted = 0;"
  con.connect();
  con.query(query, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function getParticipantsById(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "SELECT id,name FROM Participant WHERE deleted = 0 AND id = ? ORDER BY NAME ASC;"
  var inserts = [req.query.id];
  con.connect();
  con.query(query, inserts, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function getResultatsPersonnels(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "SELECT  Participant.id as id, Participant.name as name, score, Equipe.name AS equipe_name, createdAt AS date FROM Score  JOIN Participant ON Participant.id=Score.participantId  JOIN Equipe ON Score.equipeId = Equipe.id  WHERE  (Score.deleted = 0 AND ( Participant.deleted=0 AND Participant.id=?)) ORDER BY date ASC;"
  var inserts = [req.query.id];
  con.connect();
  con.query(query, inserts, (err, result) => {
    if (err) {
      console.log(err);
      return res.send(
        {
          data: [],
          distTotale: 0,
          distMax: 0,
          nbScores: 0,
          distMoy: 0,
        }
      )
    }
    let leader_indiv = {
      dataperf: [],
      distTotale: 0,
      distMax: 0,
      nbScores: 0,
      distMoy: 0,
    };
    for (const data of result) {
      //if(Object.keys(leader_indiv).length > 0){
      if ((leader_indiv.dataperf).length > 0) {
        leader_indiv.distTotale += data.score;
        leader_indiv.distMax = Math.max(data.score, leader_indiv.distMax);
        leader_indiv.nbScores += 1;
        leader_indiv.distMoy = leader_indiv.distTotale / leader_indiv.nbScores;
      } else {
        leader_indiv = {
          dataperf: result,
          distTotale: data.score,
          distMax: data.score,
          nbScores: 1,
          distMoy: data.score,
        }
      }
    }
    //result = Object.keys(leader_indiv).map((key) => leader_indiv[key])
    return res.send(leader_indiv)
  });
  con.end();
}

function addNewParticipant(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "INSERT INTO `Participant` (`name`) VALUES (?);"
  var inserts = [req.body.name];
  con.connect();
  con.query(query, inserts, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function addNewParticipantWithId(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "INSERT IGNORE INTO `Participant` (`id`, `name`) VALUES (?,?);"
  var inserts = [req.body.id, req.body.name];
  con.connect();
  con.query(query, inserts, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function updateParticipant(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "UPDATE Participant SET name = ? WHERE id=?;"
  var inserts = [req.body.name, req.body.id];
  con.connect();
  con.query(query, inserts, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function deleteParticipant(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "UPDATE Participant SET deleted = 1 WHERE id=?;"
  var inserts = [req.body.id];
  con.connect();
  con.query(query, inserts, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

module.exports = { getClassementIndividuel, getParticipants, addNewParticipant, updateParticipant, deleteParticipant, getNombreParticipants, addNewParticipantWithId, getParticipantsById, getParticipantsIdentifiants, getResultatsPersonnels }
