const mysql = require('mysql');
var secrets = require('../secrets.js');
var dbhost = secrets.dbhost;
var dbuser = secrets.dbuser;
var dbpassword = secrets.dbpassword;
var dbdatabase = secrets.dbdatabase;

const dbConfig = {
  host: dbhost,
  user: dbuser,
  password: dbpassword,
  database: dbdatabase
};

function getStaffeurs(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "SELECT id,login FROM Staffeurs WHERE deleted = 0 ORDER BY login ASC;"
  con.connect();
  con.query(query, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function addNewStaffeur(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "INSERT INTO `Staffeurs` (`login`) VALUES (?);"
  var inserts = [req.body.login];
  con.connect();
  con.query(query, inserts, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function deleteStaffeur(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "UPDATE Staffeurs SET deleted = 1 WHERE id=?;"
  var inserts = [req.body.id];
  con.connect();
  con.query(query, inserts, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    return res.send(result)
  });
  con.end();
}

function getStaffeursLogins(req, res) {
  var con = mysql.createConnection(dbConfig);
  var query = "SELECT login FROM Staffeurs WHERE deleted = 0;"
  con.connect();
  con.query(query, (err, result) => {
    if (err) {
      console.log(err)
      return res.send({ success: false })
    }
    var data = result.map((item) => { return item.login });
    return res.send(data)
  });
  con.end();
}

function simple_query(query, args) {
  var connection = mysql.createConnection(dbConfig);
  connection.connect();
  return new Promise((resolve, reject) => {
    var sql = mysql.format(query, args);
    connection.query(sql, function (error, results) {
      if (error) {
        console.log(error)
        reject(error)
      }
      else {
        resolve(JSON.parse(JSON.stringify(results)))
      }
    });
    connection.end();
  })
}

async function isStaffMiddleware(req, res, next) {
  const login = req.session.ids.login || '';
  var query = "SELECT login FROM Staffeurs WHERE deleted = 0;"

  const staffeurs = await simple_query(query, []);
  const staffeursList = staffeurs.map((item) => item.login);

  if (staffeursList.includes(login)) {
    return next();
  }
  res.status(403);
}


module.exports = { getStaffeurs, addNewStaffeur, deleteStaffeur, getStaffeursLogins, isStaffMiddleware }
