var express = require('express');
const session = require('express-session');
var cookieParser = require('cookie-parser');

var apiRouter = require('./routes/api');
var apiAdminRouter = require('./routes/apiAdmin');
var apiStaffRouter = require('./routes/apiStaff');
var oauth = require('./controllers/auth.controller');
var admin = require('./controllers/administrateur.controller');
var staff = require('./controllers/staffeurs.controller');

var app = express();

app.use(cookieParser());
app.use(session({ secret: 'mysecretsession' }));

app.use(express.json());
app.use(express.urlencoded({ extended: false }));

app.use('/api', apiRouter);
app.use('/api/staff', oauth.authMiddleware, staff.isStaffMiddleware, apiStaffRouter);
app.use('/api/admin', oauth.authMiddleware, admin.isAdminMiddleware, apiAdminRouter);

app.get('/api/login', function (req, res) {
  res.redirect(oauth.getRedirectURI());
});

app.get('/api/fallback', async function (req, res) {
  var token = await oauth.getToken(req.query.code);
  req.session.ids = await oauth.getInfos(token)
  res.redirect("/");
});

app.get('/api/user', function (req, res) {
  res.send(req.session.ids);
});

app.get('/api/logout', function (req, res) {
  req.session.destroy();
  res.redirect('/');
});

var port = process.env.PROD ? 8000 : 5000;

app.listen(port, () => {
  console.log(`App server now listening on port ${port}`);
});

module.exports = app;
